<?php

class xx_cache_sys{

    /**
     * 插入系统缓存。
     *
     * 该方法用于将给定的数据插入到系统的缓存中。
     * 主要用于提高系统性能，通过缓存经常访问但不经常变化的数据。
     *
     * @param string $cachename 缓存的名称，用于唯一标识缓存数据。
     * @param mixed $data 要插入缓存的数据，可以是任何类型。
     * @return bool 插入操作的执行结果，成功返回true，失败返回false。
     */
    public static function insert_syscache($cachename, $data){
        $var =  C::t('common_syscache')->insert_syscache($cachename, $data);
        return $var;
    }

    /**
     * 更新系统缓存。
     *
     * 当缓存中的数据发生变化时，可以通过该方法来更新缓存，
     * 以确保缓存中的数据与数据库中的数据保持同步。
     *
     * @param string $cachename 缓存的名称，用于唯一标识缓存数据。
     * @param mixed $data 更新后的缓存数据。
     * @return bool 更新操作的执行结果，成功返回true，失败返回false。
     */
    public static function update_syscache($cachename, $data)
    {
        $var =  C::t('common_syscache')->update_syscache($cachename, $data);
        return $var;
    }

    /**
     * 删除系统缓存。
     *
     * 该方法用于删除指定名称的缓存数据，或者批量删除多个缓存数据。
     * 当缓存中的数据不再需要或者缓存数据已经过期时，可以调用该方法进行清理。
     *
     * @param array|string $cachenames 要删除的缓存名称，可以是单个名称或名称的数组。
     * @return bool 删除操作的执行结果，成功返回true，失败返回false。
     */
    public static function delete_syscache($cachenames)
    {
        $var =  C::t('common_syscache')->delete_syscache($cachenames);
        return $var;
    }

    /**
     * 获取所有系统缓存。
     *
     * 该方法用于批量获取指定名称的缓存数据，可以用于一次性获取多个缓存数据，
     * 提高数据获取的效率。
     *
     * @param array|string $cachenames 要获取的缓存名称，可以是单个名称或名称的数组。
     * @return array 获取的缓存数据数组。
     */
    public static function fetch_all_syscache($cachenames)
    {
        $var =  C::t('common_syscache')->fetch_all_syscache($cachenames);
        return $var;
    }
    /**
     * 从系统缓存中获取指定缓存名称的数据
     *
     * 此静态方法用于从系统的系统缓存表中检索指定缓存名的数据。它封装了对缓存数据检索的过程，
     * 提供了一个简化的接口，以便在不直接操作数据库的情况下获取缓存数据。
     *
     * @param string $cachename 指定要获取的缓存的名称。缓存名称是缓存数据在系统中唯一标识的关键字。
     * @return mixed 返回从缓存中获取的数据。如果缓存不存在或已过期，则返回null。
     */
    public static function fetch_syscache($cachename)
    {
        // 通过调用common_syscache类的方法来获取指定缓存名的缓存数据
        $var = C::t('common_syscache')->fetch_syscache($cachename);
        // 返回获取到的缓存数据
        return $var;
    }
}



class xx_cache_sql{
    /**
     * 获取内存cache_sql值
     * @param // ids为变量id
     * @param // 如果为真返回所有内存值信息，如果为空返回变量值
     * @return bool//成功返回真、否则返回假
     */
    public static function get_cache($ids,$type=false){
        if ($type){
            $data = DB::fetch_first('select * from %t where ids=%d',array('xinxiuvip_network_cache',$ids));
            return $data;
        }else{
            $data = DB::result_first('select cache_vlaue from %t where ids=%d',array('xinxiuvip_network_cache',$ids));
            return $data;
        }
    }

    /**
     * 设置内存cache_sql值
     * @param $id // id为变量id
     * @param $value // 为设置变量值
     * @return bool//成功返回真、否则返回假
     */
    public static function set_cache($ids,$value=''){
        if ($value){
            $value = trim(addslashes($value));
            $data =  DB::update('xinxiuvip_network_cache',array('cache_vlaue' => $value),array('ids'=> $ids),true,true);
            if ($data){
                return true;
            }else{
                return false;
            }
        }else{
            return false;
        }
    }
}
    class xx_cache{
        /**
         * 获取data文件列表内缓存文件列表
         * @param $pathfile //缓存目录名称 例子：'mulu/mulu1' /斜杠两侧都是文件名
         * @return array|false //返回对应文件下所有缓存变量名
         */
        public static function cache_list($pathfile){

            $file = DISCUZ_ROOT.'data/cache/xinxiuvip_network/'.$pathfile.'/';
            $path_arr = scandir($file);
            foreach($path_arr as $key => $value){
                if ($value == '.' or $value == '..'){
                    unset($path_arr[$key]);
                }
                $path_arr[$key] = basename($path_arr[$key],".json");
            }

            return array_merge($path_arr);
        }
        /**
         * 获取指定缓存变量值
         * @param $pathfile //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param array $keys //获取缓存值数组，支持N级读取，array('key','key1',...) ，
         * 如果为空，返回全部数组或文本
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return mixed
         */
        public static function get_cache($pathfile,$keys = array(),$crypt=false)
        {
            $file = self::cache_is($pathfile);
            $json = file_get_contents($file);
            /**
             *判断如果获取数据加密的，则解密
             */
            $crypt ? $json = self::crypt_D($json) : true;
            //===========================================

            $array = xx_convert::json_decode($json);


            if (is_array($array)) {
                if (is_array($keys) AND !empty($keys)) {
                    $key_arr = $array;
                    foreach ($keys as $value) {
                        if (empty($value)) {
                            continue;
                        }
                        $key_arr = $key_arr[$value];
                    }
                    return $key_arr;
                }else{
                    return $array;
                }
            } else {
                return $json;
            }
        }

        /**
         * 设置指定缓存变量值
         * @param $pathfile //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param array $keys //设置缓存值数组，支持N级设置，array('key'=>array('keys',''keys1'),'key1'=>'demo',...) ，
         * 如果不是数组设置为指定文本
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return mixed
         */
        public static function set_cache($pathfile,$keys = array(),$crypt=false){
            $file = self::cache_is($pathfile);
            
            if (is_array($keys)){
                /**
                 *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                 */
                $crypt ? $data = self::crypt_E(xx_convert::json_encode($keys)) : $data = xx_convert::json_encode($keys);

                $put =file_put_contents($file,$data,LOCK_EX);
            }else{
                /**
                 *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                 */
                $crypt ? $data = self::crypt_E($keys) : $data = $keys;

                $put =file_put_contents($file,$data,LOCK_EX);
            }
            if ($put){
                return true;
            }else{
                return false;
            }
        }
        protected static function crypt_E($str){//加密
            return xx_crypt::encrypt_E($str,'www_xinxiuvip.com');
        }
        protected static function crypt_D($str){//解密
            return xx_crypt::encrypt_D($str,'www_xinxiuvip.com');
        }
        /**
         * 合并数组缓存文件
         * @param $pathfile //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param array $keys //新增缓存文件，数组型，如果两个或更多个数组元素有相同的键名，则最后的元素会覆盖其他元素。
         * 如果是文本加入数组，或者数组加入文本，文本加入文本都不会覆盖
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return mixed
         */

        public static function add_cache($pathfile,$keys = array(),$crypt=false){
            if (!empty($keys)){
                $file = self::cache_is($pathfile);
                $json = file_get_contents($file);

                /**
                 *判断如果获取数据加密的，则解密
                 */
                $crypt ? $json = self::crypt_D($json) : true;
                //===========================================

                $array = xx_convert::json_decode($json);
                if (is_array($array)){
                    if (is_array($keys)){
                        $array = array_merge($array,$keys);
                        /**
                         *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                         */
                        $crypt ? $data = self::crypt_E(xx_convert::json_encode($array)) : $data = xx_convert::json_encode($array);

                        $put =file_put_contents($file,$data,LOCK_EX);
                    }else{
                        $array = array_merge($array,array($keys));
                        /**
                         *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                         */
                        $crypt ? $data = self::crypt_E(xx_convert::json_encode($array)) : $data = xx_convert::json_encode($array);

                        $put =file_put_contents($file,$data,LOCK_EX);
                    }
                }else{
                    if (is_array($keys)){
                        $array = array_merge(array($array),$keys);
                        /**
                         *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                         */
                        $crypt ? $data = self::crypt_E(xx_convert::json_encode($array)) : $data = xx_convert::json_encode($array);

                        $put =file_put_contents($file,$data,LOCK_EX);
                    }else{
                        $array = $json . $keys;
                        /**
                         *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                         */
                        $crypt ? $data = self::crypt_E($array) : $data = $array;

                        $put =file_put_contents($file,$data,LOCK_EX);
                    }
                }
                if ($put){
                    return true;
                }else{
                    return false;
                }
            }else{
                return false;
            }
        }

        /**
         * 出栈数组最后一个元素
         * @param $pathfile//缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return false|mixed|null
         */
        public static function pop_cache($pathfile,$crypt=false){
            $file = self::cache_is($pathfile);
            $json = file_get_contents($file);
            /**
             *判断如果获取数据加密的，则解密
             */
            $crypt ? $json = self::crypt_D($json) : true;
            //===========================================
            $array = xx_convert::json_decode($json);

            if (is_array($array)){
                $out = array_pop($array);
                /**
                 *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                 */
                $crypt ? $data = self::crypt_E(xx_convert::json_encode($array)) : $data = xx_convert::json_encode($array);
                //============================================
                $put =file_put_contents($file,$data,LOCK_EX);
                if ($put){
                    return $out;
                }else{
                    return false;
                }
            }else{
                return false;
            }
        }
        /**
         * 查询所有一维数组键名与键值对应键名
         * @param $pathfile //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param null $type //输入键值反查对应的键名，如果为空，则返回所有键名
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return int[]|string[]
         */
        public static function keys_cache($pathfile,$type = null,$crypt=false){
            $file = self::cache_is($pathfile);
            $json = file_get_contents($file);
            /**
             *判断如果获取数据加密的，则解密
             */
            $crypt ? $json = self::crypt_D($json) : true;
            //===========================================
            $array = xx_convert::json_decode($json);
            if (is_array($array)){
                if (empty($type)){
                    return array_keys($array);
                }else{
                    return array_keys($array,$type);
                }
            }else{
                return false;
            }

        }
        /**
         *返回随机键名，即抽奖程序
         * @param $pathfile //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param 1 $int //输入返回随机键值的数量，默认为1
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return int[]|string[]
         */
        public static function rand_cache($pathfile,$int = 1,$crypt=false){
            $file = self::cache_is($pathfile);
            $json = file_get_contents($file);
            /**
             *判断如果获取数据加密的，则解密
             */
            $crypt ? $json = self::crypt_D($json) : true;
            //===========================================
            $array = xx_convert::json_decode($json);
            if (is_array($array)){
                return array_rand($array,$int);
            }else{
                return false;
            }

        }
        /**
         * 输入对应值，搜索对应键名
         * @param $pathfile  //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param $type  //输入键值反查对应的键名，不能为空，则返回所有键名
         * @param false $strict //默认为假，如果设置为 true，则在数组中检查给定值的类型，数字 5 和字符串 5 是不同的
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return false|int|string
         */
        public static function search_cache($pathfile,$type,$strict = false,$crypt=false){
            $file = self::cache_is($pathfile);
            $json = file_get_contents($file);
            /**
             *判断如果获取数据加密的，则解密
             */
            $crypt ? $json = self::crypt_D($json) : true;
            //===========================================
            $array = xx_convert::json_decode($json);
            if (is_array($array)){
                return array_search($type,$array,$strict);
            }else{
                return false;
            }
        }

        /**
         * 删除指定变量值及变量缓存文件
         * @param $pathfile //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @param null $keys //缓存数组keys目前只支持五级数组
         * @param bool $crypt // 是否是加密数据，默认为假
         * @return bool|int|void
         */
        public static function del_cache($pathfile,$keys = array(),$crypt=false){
            $file = self::cache_is($pathfile);
            $json = file_get_contents($file);
            /**
             *判断如果获取数据加密的，则解密
             */
            $crypt ? $json = self::crypt_D($json) : true;
            //===========================================
            $array = xx_convert::json_decode($json);

            if (is_array($array)){
                if (empty($keys)){
                    return unlink($file);
                }else{
                    $arr_count = count($keys);

                    if ($arr_count == 1){
                        unset($array[$keys[0]]);
                    }elseif ($arr_count == 2){
                        unset($array[$keys[0]][$keys[1]]);
                    }elseif ($arr_count == 3){
                        unset($array[$keys[0]][$keys[1]][$keys[2]]);
                    }elseif ($arr_count == 4){
                        unset($array[$keys[0]][$keys[1]][$keys[2]][$keys[3]]);
                    }elseif ($arr_count == 5){
                        unset($array[$keys[0]][$keys[1]][$keys[2]][$keys[3]][$keys[4]]);
                    }else{
                        return false;
                    }
                    /**
                     *判断是否加密，如果加密，json后加密存入，如果为空则json加密存入
                     */
                    $crypt ? $data = self::crypt_E(xx_convert::json_encode($array)) : $data = xx_convert::json_encode($array);
                    //============================================
                    $put =file_put_contents($file,$data,LOCK_EX);

                    if ($put){
                        return true;
                    }else{
                        return false;
                    }
                }
            }else{
                return unlink($file);
            }
        }
        /**
         * 生成缓存目录文件
         * @param $pathfile //缓存目录及文件名称 例子：'mulu/mulu1/wenjian' /斜杠前面都是目录，最后面是文件名
         * @return string //如果不存在则创建空文本，返回文件指定目录地址
         */
        /**
         * 构建并检查缓存文件路径
         *
         * 本函数接收一个文件路径字符串，将其转换为缓存系统中对应的文件路径，并确保该路径的文件或文件夹存在
         * 如果指定的文件不存在，则会创建一个空的JSON文件
         *
         * @param string $pathfile 原始文件路径字符串
         * @return string 返回转换后的缓存文件路径
         */
        public static function cache_is($pathfile){
            // 将输入的文件路径分割成数组
            $file_arr = explode('/',trim($pathfile));
            // 定义缓存文件的根目录
            $file = DISCUZ_ROOT.'data/cache/xinxiuvip_network/';
            // 确保根目录存在，如果不存在则递归创建
            if (!file_exists($file)){
                mkdir(dirname($file),0777, true);
                mkdir($file,0777, true);
            }
            // 遍历文件路径数组，构建缓存文件路径
            foreach($file_arr as $value){
                // 跳过空的路径部分
                if (empty($value)){
                    continue;
                }
                // 如果是路径中的最后一部分，则添加.json后缀
                if ($value == end($file_arr)){
                    $file .= $value.'.json';
                }else{
                    // 否则，添加路径分隔符并创建对应的文件夹
                    $file .= $value.'/';
                   // mkdir($file,0777, true);
                    if (!is_dir($file)) {
                        // 目录不存在，创建它
                        mkdir($file, 0777, true); // 第三个参数设置为true以递归创建多级目录
                    }
                }
            }
            // 如果最终的文件不存在，则创建一个空的JSON文件
            if (!file_exists($file)){
                file_put_contents($file,xx_convert::json_encode(array()),LOCK_EX);
            }
            // 返回转换后的缓存文件路径
            return $file;
        }
    
        /**
         * 格式化缓存目录
         * @param $files
         * @return string
         *   xx_cache::cache_file('down/log/index.htm');//格式化目录
         */
        public static function cache_file($files){
            $file_arr = explode('/',trim($files));
            $file = DISCUZ_ROOT.'data/cache/xinxiuvip_network/';
            if (!file_exists($file)){
                mkdir(dirname($file),0777, true);
                mkdir($file,0777, true);
            }else{
                mkdir(dirname($file),0777, true);
                mkdir($file,0777, true);
            }
            foreach($file_arr as $value){
                if (empty($value)){
                    continue;
                }
                if ($value == end($file_arr)){
                    
                    $file .= $value;
                }else{
                    $file .= $value.'/';
                    mkdir($file,0777, true);
                }
            }
            if (!file_exists($file)){
                file_put_contents($file,xx_convert::json_encode(array()),LOCK_EX);
            }
            return $file;
        }
        /**
         * 格式化缓存目录
         * @param $files
         * @return string
         *   xx_cache::cache_file('down/log/index.htm');//格式化目录
         */
        public static function cache_file_plugin($files){
            if (!file_exists($files)){
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files))))))))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files)))))))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files))))))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files)))))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files))))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files)))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files)))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files))))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files)))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname(dirname($files))))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname(dirname($files)))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname(dirname($files))))),0777, true);
                mkdir(dirname(dirname(dirname(dirname($files)))),0777, true);
                mkdir(dirname(dirname(dirname($files))),0777, true);
                mkdir(dirname(dirname($files)),0777, true);
                mkdir(dirname($files),0777, true);
            }
            return $files;
        }
        /**
         * 验证文件时间是否超过某个时间单位为秒
         * @param $pathfile
         * @param $time
         * 超过时间返回假，没找过返回真
         */
        public static function cache_time($pathfile,$time){//加载网络验证信息
            $file = xx_cache::cache_is($pathfile); //获取存放json缓存文件地址
            $stat = stat($file); //获取文件信息，找到最后一次修改时间
            clearstatcache();//删除stat()缓存
            if (($stat['mtime']  + $time) < time()){ //对比最后一次修改时间是不是24小时之后
                return true;
            }else{
                return false;
            }
        }
    }